==> nextcloud-22.2.5.tar.bz2: nextcloud/apps/files_sharing/l10n/nb.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delt med deg",
    "Nothing shared with you yet" : "Ingenting er delt med deg enda",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg vil bli vist her",
    "Shared with others" : "Delt med andre",
    "Nothing shared yet" : "Ingenting er delt ennå",
    "Files and folders you share will show up here" : "Filer og mapper som du deler vil bli vist her",
    "Shared by link" : "Delt med lenke",
    "No shared links" : "Ingen delte lenker",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenke vil bli vist her",
    "Deleted shares" : "Slettede delinger",
    "No deleted shares" : "Ingen slettede delinger",
    "Shares you deleted will show up here" : "Delinger du har slettet vil vises her",
    "Pending shares" : "Ventende delinger",
    "No pending shares" : "Ingen ventende delinger",
    "Shares you have received but not confirmed will show up here" : "Delinger du har mottatt men ikke bekreftet vil vises her",
    "Shares" : "Delinger",
    "No shares" : "Ingen delinger",
    "Shares will show up here" : "Delinger vil vises her",
    "Restore" : "Gjenopprett",
    "Restore share" : "Gjenopprett deling",
    "Something happened. Unable to restore the share." : "Noe skjedde. Ikke mulig å gjenopprette delingen.",
    "Accept share" : "Aksepter deling",
    "Something happened. Unable to accept the share." : "Noe skjedde. Ikke mulig å motta delingen.",
    "Reject share" : "Avvis deling",
    "Something happened. Unable to reject the share." : "Noe skjedde. Ikke mulig å avvise delingen.",
    "Waiting…" : "Venter...",
    "error" : "feil",
    "finished" : "fullført",
    "This will stop your current uploads." : "Dette fille stoppe dine nåværende opplastinger.",
    "Move or copy" : "Flytt eller kopier",
    "Download" : "Last ned",
    "Delete" : "Slett",
    "You can upload into this folder" : "Du kan laste opp til denne mappen",
    "Terms of service" : "Betingelser for tjenesten",
    "No compatible server found at {remote}" : "Ingen kompatibel server ble funnet på {remote}",
    "Invalid server URL" : "Ugyldig server adresse",
    "Failed to add the public link to your Nextcloud" : "Feil oppstod under oppretting av offentlig lenke til din Nextcloud",
    "No expiration date set" : "Ingen utløpsdato er satt",
    "Shared by" : "Delt av",
    "File shares" : "Fildelinger",
    "Downloaded via public link" : "Nedlastet via offentlig lenke",
    "Downloaded by {email}" : "Lastet ned av {email}",
    "{file} downloaded via public link" : "{file} lastet ned via offentlig lenke",
    "{email} downloaded {file}" : "{email} lastet ned {file}",
    "Shared with group {group}" : "Delt med gruppen {group}",
    "Removed share for group {group}" : "Fjernet deling for gruppen {group}",
    "{actor} shared with group {group}" : "{actor} delt med gruppen {group}",
    "{actor} removed share for group {group}" : "{actor} fjernet deling for gruppen {group}",
    "Share for group {group} expired" : "Deling for gruppen {group} utløpt",
    "You shared {file} with group {group}" : "Du delte {file} med gruppen {group}",
    "You removed group {group} from {file}" : "Du fjernet gruppen {group} fra {file}",
    "{actor} shared {file} with group {group}" : "{actor} delte {file} med gruppen {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjernet gruppen {group} fra {file}",
    "Share for file {file} with group {group} expired" : "Deling for filen {file} med gruppen {group} utløpt",
    "Shared as public link" : "Delt som offentlig lenke",
    "Removed public link" : "Fjernet offentlig lenke",
    "Public link expired" : "Offentlig lenke er utløpt",
    "{actor} shared as public link" : "{actor} delte som offentlig lenke",
    "{actor} removed public link" : "{actor} fjernet offentlig lenke",
    "Public link of {actor} expired" : "Offentlig lenke av {actor} er utløpt",
    "You shared {file} as public link" : "Du delte {file} som offentlig lenke",
    "You removed public link for {file}" : "Du fjernet offentlig lenke for {file}",
    "Public link expired for {file}" : "Offentlig lenke er utløprt for {file}",
    "{actor} shared {file} as public link" : "{actor} delte {file} som offentlig lenke",
    "{actor} removed public link for {file}" : "{actor} fjernet offentlig lenke for {file}",
    "Public link of {actor} for {file} expired" : "Offentlig lenke av {actor} for {file} har utløpt",
    "{user} accepted the remote share" : "{user} godtok fjerndelingen",
    "{user} declined the remote share" : "{user} avslo fjerndelingen",
    "You received a new remote share {file} from {user}" : "Du har mottatt en ny fjerndeling {file} fra {user}",
    "{user} accepted the remote share of {file}" : "{user} godtok fjerndelingen av {file}",
    "{user} declined the remote share of {file}" : "{user} avslo fjerndelingen av {file}",
    "{user} unshared {file} from you" : "{user} opphevde deling av {file} med deg",
    "Shared with {user}" : "Delt med {user}",
    "Removed share for {user}" : "Fjernet deling med {user}",
    "You removed yourself" : "Du fjernet deg selv",
    "{actor} removed themselves" : "{actor} fjernet seg selv",
    "{actor} shared with {user}" : "{actor} delte med {user}",
    "{actor} removed share for {user}" : "{actor} fjernet deling med {user}",
    "Shared by {actor}" : "Delt av {actor}",
    "{actor} removed share" : "{actor} fjernet deling",
    "Share for {user} expired" : "Deling for {user} utløpt",
    "Share expired" : "Deling utløpt",
    "You shared {file} with {user}" : "Du delte {file} med {user}",
    "You removed {user} from {file}" : "Du fjernet {user} fra {file}",
    "You removed yourself from {file}" : "Du fjernet deg selv fra {file}",
    "{actor} removed themselves from {file}" : "{actor} fjernet seg selv fra {file}",
    "{actor} shared {file} with {user}" : "{actor} delete {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} fjernet {user} fra {file}",
    "{actor} shared {file} with you" : "{actor} delte {file} med deg",
    "{actor} removed you from the share named {file}" : "{actor} fjernet deg fra delingen kalt {file}",
    "Share for file {file} with {user} expired" : "Deling for fil {file} med {user} utløpt",
    "Share for file {file} expired" : "Deling for fil {file} utløpt",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Ei fil eller mappe delt via e-post eller offentlig lenke ble <strong>lastet ned</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen server</strong>",
    "Files" : "Filer",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
    "Shared link" : "Delte lenke",
    "Wrong share ID, share doesn't exist" : "Feil ressurs ID, ressursen finnes ikke",
    "Could not delete share" : "Kunne ikke slette ressursen",
    "Please specify a file or folder path" : "Oppgi en fil eller mappesti",
    "Wrong path, file/folder doesn't exist" : "Feil filbane, filen/mappen finnes ikke",
    "Could not create share" : "Kunne ikke opprette ressurs",
    "Invalid permissions" : "Ugyldig rettigheter",
    "Please specify a valid user" : "Oppgi en gyldig bruker",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktivert av administratoren",
    "Please specify a valid group" : "Oppgi en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Administratoren har skrudd av offentlig lenkedeling",
    "Public upload disabled by the administrator" : "Offentlig opplasting er deaktivert av administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentlig opplasting er kun mulig i offentlig delte mapper",
    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
    "Please specify a valid federated user ID" : "Angi en gyldig sammenknyttet brukersky-ID",
    "Please specify a valid federated group ID" : "Angi en gyldig sammenknyttet gruppesky-ID",
    "You cannot share to a Circle if the app is not enabled" : "Du kan ikke dele til en sirkel så lenge appen ikke er aktivert",
    "Please specify a valid circle" : "Angi en gyldig sirkel",
    "Unknown share type" : "Ukjent ressurstype",
    "Not a directory" : "Ikke en mappe",
    "Could not lock path" : "Kunne ikke låse sti",
    "Wrong or no update parameter given" : "Feil eller ingen parametre for oppdatering er angitt",
    "Cannot change permissions for public share links" : "Kan ikke endre rettigheter for offentlig delingslenker",
    "shared by %s" : "delt av %s",
    "Download all files" : "Last ned alle filer",
    "Direct link" : "Direkte lenke",
    "Add to your %s" : "Legg til din %s",
    "Share API is disabled" : "Deling API er deaktivert",
    "File sharing" : "Fildeling",
    "Share will expire tomorrow" : "Deling utløper i morgen",
    "One or more of your shares will expire tomorrow" : "En eller flere av delingene dine utløper i morgen",
    "You received {share} as a share by {user}" : "Du mottok {share} som en deling fra {user}",
    "You received {share} to group {group} as a share by {user}" : "Du mottok {share} til gruppen {group} som en deling fra {user}",
    "Accept" : "Aksepter",
    "Reject" : "Avvis",
    "Sharing" : "Deling",
    "Allow editing" : "Tillat redigering",
    "Allow creating" : "Tillat oppretting",
    "Allow deleting" : "Tillat sletting",
    "Allow resharing" : "TIllat videre deling",
    "Expiration date enforced" : "Utløpsdato er påkrevd",
    "Set expiration date" : "Sett utløpsdato",
    "Enter a date" : "Skriv inn dato",
    "Note to recipient" : "Melding til mottaker",
    "Unshare" : "Opphev deling",
    "group" : "gruppe",
    "conversation" : "samtale",
    "remote" : "ekstern",
    "remote group" : "ekstern gruppe",
    "guest" : "gjest",
    "Internal link" : "Intern lenke",
    "Link copied" : "Lenke kopiert",
    "Copy to clipboard" : "Kopiert til utklippstavlen",
    "Only works for users with access to this folder" : "Virker kun for brukere med tilgang til mappen",
    "Only works for users with access to this file" : "Virker kun for brukere med tilgang til denne filen",
    "Password protection" : "Passordbeskyttelse",
    "Enter a password" : "Skriv inn et passord",
    "Create share" : "Opprett deling",
    "Cancel" : "Avbryt",
    "Share label" : "Delingsmerkelapper",
    "Read only" : "Skrivebeskyttet",
    "Allow upload and editing" : "Tillatt opplasting og redigering",
    "File drop (upload only)" : "Filkasse (kun opplasting)",
    "Hide download" : "Gjem nedlasting",
    "Password protect" : "Passordbeskyttelse",
    "Enter a note for the share recipient" : "Skriv inn en beskjed til mottaker av deling",
    "Add another link" : "Legg til en lenke til",
    "Create a new share link" : "Opprett ny delingslenke",
    "Share link ({label})" : "Del lenke ({label})",
    "Share link" : "Share link",
    "No recommendations. Start typing." : "Ingen forslag. Start skriving.",
    "Resharing is not allowed" : "Videre deling er ikke tillatt",
    "Name or email …" : "Navn eller epost ...",
    "Name, email, or Federated Cloud ID …" : "Navn, epost eller sammenknyttet sky-ID ...",
    "Searching …" : "Søker ...",
    "No elements found." : "Ingen elementer funnet.",
    "Search globally" : "Søk globalt",
    "on {server}" : "på {server}",
    "Others with access" : "Andre med tilgang",
    "No other users with access found" : "Ingen andre brukere med tilgang funnet",
    "Toggle list of others with access to this directory" : "Endre liste over andre brukere med tilgang til denne mappen",
    "Toggle list of others with access to this file" : "Endre liste over andre brukere med tilgang til denne filen",
    "this share just expired." : "denne delingen utløp akkurat.",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "Link to a file" : "Lenke til en fil",
    "Shared" : "Delt",
    "Share" : "Del",
    "Shared with" : "Delt med",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppen {group} av {owner}",
    "Shared with you and {circle} by {owner}" : "Delt med deg og {circle} av {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Delt med deg og samtalen {conversation} av {owner}",
    "Shared with you in a conversation by {owner}" : "Delt md deg i samtale med  {owner}",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Share time" : "Delingstidspunkt",
    "Expiration date" : "Utløpsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "Reasons might be:" : "Mulige årsaker:",
    "the item was removed" : "elementet er fjernet",
    "the link expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er avskrudd",
    "For more info, please ask the person who sent this link." : "For mer informasjon, spør personen som sendte lenken.",
    "Share note" : "Delingsnotat",
    "Toggle grid view" : "Veksle rutenett-visning",
    "Upload files to %s" : "Last opp filer til %s",
    "Note" : "Melding",
    "Select or drop files" : "Velg eller slipp filer",
    "Uploading files" : "Laster opp filer",
    "Uploaded files:" : "Opplastede filer:",
    "Add to your Nextcloud" : "Legg til i din Nextcloud",
    "invalid permissions" : "Ugyldige rettigheter",
    "Can't change permissions for public share links" : "Kan ikke endre rettigheter for offentlige lenker",
    "Name, email, or federated cloud ID …" : "Navn, epost eller sammenknyttet sky-ID ...",
    "Download %s" : "Last ned %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/files_sharing/l10n/nb.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delt med deg",
    "Nothing shared with you yet" : "Ingenting er delt med deg enda",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg vil bli vist her",
    "Shared with others" : "Delt med andre",
    "Nothing shared yet" : "Ingenting er delt ennå",
    "Files and folders you share will show up here" : "Filer og mapper som du deler vil bli vist her",
    "Shared by link" : "Delt med lenke",
    "No shared links" : "Ingen delte lenker",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenke vil bli vist her",
    "Deleted shares" : "Slettede delinger",
    "No deleted shares" : "Ingen slettede delinger",
    "Shares you deleted will show up here" : "Delinger du har slettet vil vises her",
    "Pending shares" : "Ventende delinger",
    "No pending shares" : "Ingen ventende delinger",
    "Shares you have received but not confirmed will show up here" : "Delinger du har mottatt men ikke bekreftet vil vises her",
    "Shares" : "Delinger",
    "No shares" : "Ingen delinger",
    "Shares will show up here" : "Delinger vil vises her",
    "Restore" : "Gjenopprett",
    "Restore share" : "Gjenopprett deling",
    "Something happened. Unable to restore the share." : "Noe skjedde. Ikke mulig å gjenopprette delingen.",
    "Accept share" : "Aksepter deling",
    "Something happened. Unable to accept the share." : "Noe skjedde. Ikke mulig å motta delingen.",
    "Reject share" : "Avvis deling",
    "Something happened. Unable to reject the share." : "Noe skjedde. Ikke mulig å avvise delingen.",
    "Waiting…" : "Venter...",
    "error" : "feil",
    "finished" : "fullført",
    "This will stop your current uploads." : "Dette fille stoppe dine nåværende opplastinger.",
    "Move or copy" : "Flytt eller kopier",
    "Download" : "Last ned",
    "Delete" : "Slett",
    "You can upload into this folder" : "Du kan laste opp til denne mappen",
    "Terms of service" : "Betingelser for tjenesten",
    "Show list view" : "Vis listevisning",
    "Show grid view" : "Vis rutenett-visning",
    "No compatible server found at {remote}" : "Ingen kompatibel server ble funnet på {remote}",
    "Invalid server URL" : "Ugyldig server adresse",
    "Failed to add the public link to your Nextcloud" : "Feil oppstod under oppretting av offentlig lenke til din Nextcloud",
    "No expiration date set" : "Ingen utløpsdato er satt",
    "Shared by" : "Delt av",
    "File shares" : "Fildelinger",
    "Downloaded via public link" : "Nedlastet via offentlig lenke",
    "Downloaded by {email}" : "Lastet ned av {email}",
    "{file} downloaded via public link" : "{file} lastet ned via offentlig lenke",
    "{email} downloaded {file}" : "{email} lastet ned {file}",
    "Shared with group {group}" : "Delt med gruppen {group}",
    "Removed share for group {group}" : "Fjernet deling for gruppen {group}",
    "{actor} shared with group {group}" : "{actor} delt med gruppen {group}",
    "{actor} removed share for group {group}" : "{actor} fjernet deling for gruppen {group}",
    "Share for group {group} expired" : "Deling for gruppen {group} utløpt",
    "You shared {file} with group {group}" : "Du delte {file} med gruppen {group}",
    "You removed group {group} from {file}" : "Du fjernet gruppen {group} fra {file}",
    "{actor} shared {file} with group {group}" : "{actor} delte {file} med gruppen {group}",
    "{actor} removed group {group} from {file}" : "{actor} fjernet gruppen {group} fra {file}",
    "Share for file {file} with group {group} expired" : "Deling for filen {file} med gruppen {group} utløpt",
    "Shared as public link" : "Delt som offentlig lenke",
    "Removed public link" : "Fjernet offentlig lenke",
    "Public link expired" : "Offentlig lenke er utløpt",
    "{actor} shared as public link" : "{actor} delte som offentlig lenke",
    "{actor} removed public link" : "{actor} fjernet offentlig lenke",
    "Public link of {actor} expired" : "Offentlig lenke av {actor} er utløpt",
    "You shared {file} as public link" : "Du delte {file} som offentlig lenke",
    "You removed public link for {file}" : "Du fjernet offentlig lenke for {file}",
    "Public link expired for {file}" : "Offentlig lenke er utløprt for {file}",
    "{actor} shared {file} as public link" : "{actor} delte {file} som offentlig lenke",
    "{actor} removed public link for {file}" : "{actor} fjernet offentlig lenke for {file}",
    "Public link of {actor} for {file} expired" : "Offentlig lenke av {actor} for {file} har utløpt",
    "{user} accepted the remote share" : "{user} godtok fjerndelingen",
    "{user} declined the remote share" : "{user} avslo fjerndelingen",
    "You received a new remote share {file} from {user}" : "Du har mottatt en ny fjerndeling {file} fra {user}",
    "{user} accepted the remote share of {file}" : "{user} godtok fjerndelingen av {file}",
    "{user} declined the remote share of {file}" : "{user} avslo fjerndelingen av {file}",
    "{user} unshared {file} from you" : "{user} opphevde deling av {file} med deg",
    "Shared with {user}" : "Delt med {user}",
    "Removed share for {user}" : "Fjernet deling med {user}",
    "You removed yourself" : "Du fjernet deg selv",
    "{actor} removed themselves" : "{actor} fjernet seg selv",
    "{actor} shared with {user}" : "{actor} delte med {user}",
    "{actor} removed share for {user}" : "{actor} fjernet deling med {user}",
    "Shared by {actor}" : "Delt av {actor}",
    "{actor} removed share" : "{actor} fjernet deling",
    "Share for {user} expired" : "Deling for {user} utløpt",
    "Share expired" : "Deling utløpt",
    "You shared {file} with {user}" : "Du delte {file} med {user}",
    "You removed {user} from {file}" : "Du fjernet {user} fra {file}",
    "You removed yourself from {file}" : "Du fjernet deg selv fra {file}",
    "{actor} removed themselves from {file}" : "{actor} fjernet seg selv fra {file}",
    "{actor} shared {file} with {user}" : "{actor} delete {file} med {user}",
    "{actor} removed {user} from {file}" : "{actor} fjernet {user} fra {file}",
    "{actor} shared {file} with you" : "{actor} delte {file} med deg",
    "{actor} removed you from the share named {file}" : "{actor} fjernet deg fra delingen kalt {file}",
    "Share for file {file} with {user} expired" : "Deling for fil {file} med {user} utløpt",
    "Share for file {file} expired" : "Deling for fil {file} utløpt",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Ei fil eller mappe delt via e-post eller offentlig lenke ble <strong>lastet ned</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen server</strong>",
    "Files" : "Filer",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
    "Shared link" : "Delte lenke",
    "Could not delete share" : "Kunne ikke slette ressursen",
    "Please specify a file or folder path" : "Oppgi en fil eller mappesti",
    "Could not create share" : "Kunne ikke opprette ressurs",
    "Invalid permissions" : "Ugyldig rettigheter",
    "Please specify a valid user" : "Oppgi en gyldig bruker",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktivert av administratoren",
    "Please specify a valid group" : "Oppgi en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Administratoren har skrudd av offentlig lenkedeling",
    "Public upload disabled by the administrator" : "Offentlig opplasting er deaktivert av administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentlig opplasting er kun mulig i offentlig delte mapper",
    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
    "Please specify a valid federated user ID" : "Angi en gyldig sammenknyttet brukersky-ID",
    "Please specify a valid federated group ID" : "Angi en gyldig sammenknyttet gruppesky-ID",
    "You cannot share to a Circle if the app is not enabled" : "Du kan ikke dele til en sirkel så lenge appen ikke er aktivert",
    "Please specify a valid circle" : "Angi en gyldig sirkel",
    "Unknown share type" : "Ukjent ressurstype",
    "Not a directory" : "Ikke en mappe",
    "Could not lock path" : "Kunne ikke låse sti",
    "Wrong or no update parameter given" : "Feil eller ingen parametre for oppdatering er angitt",
    "Cannot increase permissions" : "Kan ikke øke tillatelser",
    "shared by %s" : "delt av %s",
    "Download all files" : "Last ned alle filer",
    "Direct link" : "Direkte lenke",
    "Add to your %s" : "Legg til din %s",
    "Share API is disabled" : "Deling API er deaktivert",
    "File sharing" : "Fildeling",
    "Share will expire tomorrow" : "Deling utløper i morgen",
    "One or more of your shares will expire tomorrow" : "En eller flere av delingene dine utløper i morgen",
    "Your share of {node} will expire tomorrow" : "Din deling av {node} vil løpe ut i morgen",
    "You received {share} as a share by {user}" : "Du mottok {share} som en deling fra {user}",
    "You received {share} to group {group} as a share by {user}" : "Du mottok {share} til gruppen {group} som en deling fra {user}",
    "Accept" : "Aksepter",
    "Reject" : "Avvis",
    "Sharing" : "Deling",
    "Reset" : "Tilbakestill",
    "Invalid path selected" : "Ugyldig angitt sti",
    "Unknown error" : "Ukjent feil",
    "Allow editing" : "Tillat redigering",
    "Read only" : "Skrivebeskyttet",
    "Allow upload and editing" : "Tillatt opplasting og redigering",
    "File drop (upload only)" : "Filkasse (kun opplasting)",
    "Read" : "Les",
    "Upload" : "Last opp",
    "Edit" : "Rediger",
    "Allow creating" : "Tillat oppretting",
    "Allow deleting" : "Tillat sletting",
    "Allow resharing" : "TIllat videre deling",
    "Expiration date enforced" : "Utløpsdato er påkrevd",
    "Set expiration date" : "Sett utløpsdato",
    "Enter a date" : "Skriv inn dato",
    "Note to recipient" : "Melding til mottaker",
    "Unshare" : "Opphev deling",
    "group" : "gruppe",
    "conversation" : "samtale",
    "remote" : "ekstern",
    "remote group" : "ekstern gruppe",
    "guest" : "gjest",
    "Allow download" : "Tillat nedlasting",
    "Added by {initiator}" : "Lagt til av {initiator}",
    "Via “{folder}”" : "Via “{folder}”",
    "Internal link" : "Intern lenke",
    "Link copied" : "Lenke kopiert",
    "Cannot copy, please copy the link manually" : "Kan ikke kopiere, kopier lenken manuelt",
    "Copy to clipboard" : "Kopiert til utklippstavlen",
    "Only works for users with access to this folder" : "Virker kun for brukere med tilgang til mappen",
    "Only works for users with access to this file" : "Virker kun for brukere med tilgang til denne filen",
    "Password protection" : "Passordbeskyttelse",
    "Enter a password" : "Skriv inn et passord",
    "Create share" : "Opprett deling",
    "Cancel" : "Avbryt",
    "Share label" : "Delingsmerkelapper",
    "Hide download" : "Gjem nedlasting",
    "Password protect" : "Passordbeskyttelse",
    "Enter a note for the share recipient" : "Skriv inn en beskjed til mottaker av deling",
    "Add another link" : "Legg til en lenke til",
    "Create a new share link" : "Opprett ny delingslenke",
    "{shareWith} by {initiator}" : "{shareWith} av {initiator}",
    "Shared via link by {initiator}" : "Delt via lenke av {initiator}",
    "Share link ({label})" : "Del lenke ({label})",
    "Share link" : "Share link",
    "No recommendations. Start typing." : "Ingen forslag. Start skriving.",
    "Resharing is not allowed" : "Videre deling er ikke tillatt",
    "Name or email …" : "Navn eller epost ...",
    "Name, email, or Federated Cloud ID …" : "Navn, epost eller sammenknyttet sky-ID ...",
    "Searching …" : "Søker ...",
    "No elements found." : "Ingen elementer funnet.",
    "Search globally" : "Søk globalt",
    "on {server}" : "på {server}",
    "Others with access" : "Andre med tilgang",
    "No other users with access found" : "Ingen andre brukere med tilgang funnet",
    "Toggle list of others with access to this directory" : "Endre liste over andre brukere med tilgang til denne mappen",
    "Toggle list of others with access to this file" : "Endre liste over andre brukere med tilgang til denne filen",
    "Expires {relativetime}" : "Utløper {relativetime}",
    "this share just expired." : "denne delingen utløp akkurat.",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "Link to a file" : "Lenke til en fil",
    "Error creating the share" : "Feil ved oppretting av deling",
    "Shared" : "Delt",
    "Share" : "Del",
    "Shared with" : "Delt med",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppen {group} av {owner}",
    "Shared with you and {circle} by {owner}" : "Delt med deg og {circle} av {owner}",
    "Shared with you and the conversation {conversation} by {owner}" : "Delt med deg og samtalen {conversation} av {owner}",
    "Shared with you in a conversation by {owner}" : "Delt md deg i samtale med  {owner}",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Share time" : "Delingstidspunkt",
    "Expiration date" : "Utløpsdato",
    "Reasons might be:" : "Mulige årsaker:",
    "the item was removed" : "elementet er fjernet",
    "the link expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er avskrudd",
    "For more info, please ask the person who sent this link." : "For mer informasjon, spør personen som sendte lenken.",
    "Share note" : "Delingsnotat",
    "Upload files to %s" : "Last opp filer til %s",
    "Note" : "Melding",
    "Select or drop files" : "Velg eller slipp filer",
    "Uploading files" : "Laster opp filer",
    "Uploaded files:" : "Opplastede filer:",
    "Add to your Nextcloud" : "Legg til i din Nextcloud",
    "Wrong share ID, share doesn't exist" : "Feil ressurs ID, ressursen finnes ikke",
    "Wrong path, file/folder doesn't exist" : "Feil filbane, filen/mappen finnes ikke",
    "Cannot change permissions for public share links" : "Kan ikke endre rettigheter for offentlig delingslenker",
    "Sorry, this link doesn’t seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "Toggle grid view" : "Veksle rutenett-visning"
},
"nplurals=2; plural=(n != 1);");
